Index: src/globals.h |
diff --git a/src/globals.h b/src/globals.h |
index 4cecb2f03cc024ede624fa4744c02111aa41b7a5..275ec5c522c7bcaf2a081825a553a9982d3d80fc 100644 |
--- a/src/globals.h |
+++ b/src/globals.h |
@@ -1241,8 +1241,8 @@ class BinaryOperationFeedback { |
// Type feedback is encoded in such a way that, we can combine the feedback |
// at different points by performing an 'OR' operation. Type feedback moves |
// to a more generic type when we combine feedback. |
// kSignedSmall -> kNumber -> kAny |
// kString -> kAny |
// TODO(epertoso): consider unifying this with BinaryOperationFeedback. |
class CompareOperationFeedback { |
public: |
@@ -1250,8 +1250,9 @@ class CompareOperationFeedback { |
kNone = 0x00, |
kSignedSmall = 0x01, |
kNumber = 0x3, |
- kString = 0x4, |
- kAny = 0xf |
+ kNumberOrOddball = 0x7, |
+ kString = 0x8, |
+ kAny = 0x1F |
}; |
}; |
@@ -1241,8 +1241,8 @@ class BinaryOperationFeedback { |
// at different points by performing an 'OR' operation. Type feedback moves |
// to a more generic type when we combine feedback. |
-// kSignedSmall -> kNumber -> kAny |
-// kString -> kAny |
+// kSignedSmall -> kNumber -> kNumberOrOddball -> kAny |
+// kString -> kAny |
// TODO(epertoso): consider unifying this with BinaryOperationFeedback. |
class CompareOperationFeedback { |